# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ReferralType(str, enum.Enum):
    DIRECTED = "DIRECTED"
    ROTATION = "ROTATION"
    OVERNIGHT = "OVERNIGHT"
    _UNKNOWN = "__REFERRALTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ReferralType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        directed: typing.Callable[[], T_Result],
        rotation: typing.Callable[[], T_Result],
        overnight: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ReferralType.DIRECTED:
            return directed()
        if self is ReferralType.ROTATION:
            return rotation()
        if self is ReferralType.OVERNIGHT:
            return overnight()
        return _unknown_member(self._value_)
