# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .coverage_value import CoverageValue


class ServiceCoverageDetails(UniversalBaseModel):
    copay: typing.Optional[CoverageValue] = None
    coinsurance: typing.Optional[CoverageValue] = None
    visits: typing.Optional[CoverageValue] = None
    visits_remaining: typing.Optional[CoverageValue] = None
    additional_notes: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
