# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.api_error import ApiError
from ..types.invalid_tag_names_error_type import InvalidTagNamesErrorType


class InvalidTagNamesError(ApiError):
    def __init__(self, body: InvalidTagNamesErrorType, headers: typing.Optional[typing.Dict[str, str]] = None):
        super().__init__(status_code=422, headers=headers, body=body)
