# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .patient_payment_allocation import PatientPaymentAllocation


class PatientPaymentInfo(UniversalBaseModel):
    total_payment_cents: int = pydantic.Field()
    """
    The total amount of patient payments in cents for the service line.
    """

    items: typing.List[PatientPaymentAllocation] = pydantic.Field()
    """
    A list of patient payment items associated with the service line.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
