# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .....commons.types.payer_plan_group_id import PayerPlanGroupId
from .....payers.resources.v_3.types.payer import Payer
from .mutable_payer_plan_group import MutablePayerPlanGroup


class PayerPlanGroup(MutablePayerPlanGroup):
    payer_plan_group_id: PayerPlanGroupId
    payer: Payer
    is_active: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
